@@ -15,6 +15,7 @@ from octavia_lib.common import constants
 
 # TODO(mjozefcz): Use those variables from neutron-lib once released.
 LRP_PREFIX = "lrp-"
+OVN_NAME_PREFIX = "neutron-"
 LB_VIP_PORT_PREFIX = "ovn-lb-vip-"
 OVN_PORT_NAME_EXT_ID_KEY = 'neutron:port_name'
 OVN_ROUTER_NAME_EXT_ID_KEY = 'neutron:router_name'
@@ -28,12 +29,15 @@ OVN_DEVICE_OWNER_EXT_ID_KEY = 'neutron:device_owner'
 OVN_FIP_EXT_ID_KEY = 'neutron:fip_id'
 OVN_FIP_PORT_EXT_ID_KEY = 'neutron:fip_port_id'
 OVN_GW_PORT_EXT_ID_KEY = 'neutron:gw_port_id'
+OVN_PORT_CIDR_EXT_ID_KEY = 'neutron:cidrs'
+OVN_MEMBER_STATUS_KEY = 'neutron:member_status'
 
 LB_EXT_IDS_LS_REFS_KEY = 'ls_refs'
 LB_EXT_IDS_LR_REF_KEY = 'lr_ref'
 LB_EXT_IDS_POOL_PREFIX = 'pool_'
 LB_EXT_IDS_LISTENER_PREFIX = 'listener_'
 LB_EXT_IDS_MEMBER_PREFIX = 'member_'
+LB_EXT_IDS_HM_KEY = 'octavia:healthmonitor'
 LB_EXT_IDS_VIP_KEY = 'neutron:vip'
 LB_EXT_IDS_VIP_FIP_KEY = 'neutron:vip_fip'
 LB_EXT_IDS_VIP_PORT_ID_KEY = 'neutron:vip_port_id'
@@ -60,6 +64,10 @@ REQ_TYPE_LB_CREATE_LRP_ASSOC = 'lb_create_lrp_assoc'
 REQ_TYPE_LB_DELETE_LRP_ASSOC = 'lb_delete_lrp_assoc'
 REQ_TYPE_HANDLE_VIP_FIP = 'handle_vip_fip'
 REQ_TYPE_HANDLE_MEMBER_DVR = 'handle_member_dvr'
+REQ_TYPE_HM_CREATE = 'hm_create'
+REQ_TYPE_HM_UPDATE = 'hm_update'
+REQ_TYPE_HM_DELETE = 'hm_delete'
+REQ_TYPE_HM_UPDATE_EVENT = 'hm_update_event'
 
 REQ_TYPE_EXIT = 'exit'
 
@@ -78,6 +86,10 @@ OVN_NATIVE_LB_PROTOCOLS = [constants.PROTOCOL_TCP,
                            constants.PROTOCOL_SCTP, ]
 OVN_NATIVE_LB_ALGORITHMS = [constants.LB_ALGORITHM_SOURCE_IP_PORT, ]
 
+# This driver only supports UDP Connect and TCP health monitors
+SUPPORTED_HEALTH_MONITOR_TYPES = [constants.HEALTH_MONITOR_UDP_CONNECT,
+                                  constants.HEALTH_MONITOR_TCP]
+
 # Prepended to exception log messages
 EXCEPTION_MSG = "Exception occurred during %s"
 
